import "./Accordion.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { DomProps } from "../../shared";
export interface InnerAccordionProps extends DomProps {
    /**
     * A controlled set of expanded item keys.
     */
    expandedKeys?: string[];
    /**
     * The initial value of `expandedKeys` when uncontrolled.
     */
    defaultExpandedKeys?: string[];
    /**
     * Called when an accordion item is toggled.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {String[]} keys - The keys of the expanded items.
     * @returns {void}
     */
    onExpansionChange?: (event: SyntheticEvent, keys: string[]) => void;
    /**
     * The type of expansion that is allowed.
     */
    expansionMode: "single" | "multiple";
    /**
     * Whether or not the first focusable accordion item should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerAccordion({ id, expandedKeys: expandedKeysProp, defaultExpandedKeys, onExpansionChange, expansionMode, autoFocus, as, children, forwardedRef, ...rest }: InnerAccordionProps): JSX.Element;
export declare const Accordion: import("../../shared").OrbitComponent<HTMLElement, InnerAccordionProps>;
export declare type AccordionProps = ComponentProps<typeof Accordion>;
