import "./Accordion.css";
import { AccordionContext } from "./AccordionContext";
import { AccordionItem } from "./AccordionItem";
import { Box } from "../../box";
import { Keys, forwardRef, mergeProps, useAutoFocusChild, useControllableState, useEventCallback, useFocusManager, useFocusScope, useId, useKeyboardNavigation, useMergedRefs } from "../../shared";
import { isNil, isNumber } from "lodash";
import { useAccordionItems } from "./useAccordionItems";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerAccordion({
  id,
  expandedKeys: expandedKeysProp,
  defaultExpandedKeys,
  onExpansionChange,
  expansionMode = "single",
  autoFocus,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const [expandedKeys, setExpandedKeys] = useControllableState(expandedKeysProp, defaultExpandedKeys, []);
  const [focusScope, setFocusRef] = useFocusScope();
  const containerRef = useMergedRefs(setFocusRef, forwardedRef);
  const items = useAccordionItems(children, useId(id, id ? null : "o-ui-accordion"));
  const focusManager = useFocusManager(focusScope);
  useAutoFocusChild(focusManager, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const navigationProps = useKeyboardNavigation(focusManager, {
    previous: [Keys.arrowUp],
    next: [Keys.arrowDown],
    first: [Keys.home],
    last: [Keys.end]
  });
  const handleToggle = useEventCallback((event, toggledKey) => {
    let newKeys;

    if (!expandedKeys.includes(toggledKey)) {
      if (expansionMode === "multiple") {
        newKeys = [...expandedKeys, toggledKey];
      } else {
        newKeys = [toggledKey];
      }
    } else {
      newKeys = expandedKeys.filter(x => x !== toggledKey);
    }

    if (!isNil(onExpansionChange)) {
      onExpansionChange(event, newKeys);
    }

    setExpandedKeys(newKeys);
  });
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: "o-ui-accordion",
      as,
      ref: containerRef
    }, navigationProps),
    children: /*#__PURE__*/_jsx(AccordionContext.Provider, {
      value: {
        expandedKeys: expandedKeys,
        onToggle: handleToggle
      },
      children: items.map(({
        id: itemId,
        key,
        header,
        panel
      }) => /*#__PURE__*/_jsx(AccordionItem, {
        item: {
          id: itemId,
          key,
          header,
          panel
        }
      }, key))
    })
  });
}
export const Accordion = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAccordion, { ...props,
  forwardedRef: ref
}));
Accordion.displayName = "Accordion";