import "./Accordion.css";
import { useMemo } from "react";
import { DisclosureArrow } from "../../disclosure";
import { Heading } from "../../heading";
import { adaptSize, cssModule, forwardRef, mergeProps, normalizeSize, omitProps, useSlots } from "../../shared";
import { Text } from "../../text";
import { isNil } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerAccordionHeader(props) {
  const {
    size,
    disabled,
    active,
    focus,
    hover,
    as,
    children,
    forwardedRef,
    ...rest
  } = omitProps(props, ["header"]);

  if (isNil(as)) {
    throw new Error("An accordion header must receive an \"as\" prop matching a valid heading type.");
  }

  const {
    icon,
    text
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    icon: {
      size,
      className: "o-ui-accordion-icon"
    },
    text: {
      size: "inherit",
      className: "o-ui-accordion-title"
    }
  }), [size]));
  return /*#__PURE__*/_jsx(Heading, {
    size: adaptSize(size, {
      "sm": "xs",
      "md": "sm"
    }),
    className: cssModule("o-ui-accordion-header", normalizeSize(size)),
    as: as,
    ref: forwardedRef,
    children: /*#__PURE__*/_jsxs("button", { ...mergeProps(rest, {
        className: cssModule("o-ui-accordion-trigger", active && "active", focus && "focus", hover && "hover", icon && "has-icon"),
        disabled
      }),
      type: "button",
      children: [icon, text, /*#__PURE__*/_jsx(DisclosureArrow, {
        size: size,
        className: "o-ui-accordion-arrow"
      })]
    })
  });
}
export const AccordionHeader = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAccordionHeader, { ...props,
  forwardedRef: ref
}));
AccordionHeader.displayName = "AccordionHeader";