import "./Alert.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
export interface InnerAlertProps {
    /**
     * A controlled show value.
     */
    show?: boolean;
    /**
     * The style to use.
     */
    tone?: "info" | "positive" | "warning" | "critical";
    /**
     * Called when the dismiss button is clicked.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onDismiss?: (event: SyntheticEvent) => void;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    role?: string;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerAlert({ show, tone, onDismiss, role: roleProp, as, children, forwardedRef, ...rest }: InnerAlertProps): JSX.Element;
export declare const Alert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>;
declare const InfoAlert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>, PositiveAlert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>, WarningAlert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>, CriticalAlert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>;
export interface AlertTemplateProps {
    /**
     * A controlled show value.
     */
    show?: boolean;
    /**
     * Called when the dismiss button is clicked.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onDismiss?: (event: SyntheticEvent) => void;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
}
export declare function AlertTemplate(_props: AlertTemplateProps): JSX.Element;
export declare type InfoAlertProps = ComponentProps<typeof InfoAlert>;
export declare type PositiveAlertProps = ComponentProps<typeof PositiveAlert>;
export declare type WarningAlertProps = ComponentProps<typeof WarningAlert>;
export declare type CriticalAlertProps = ComponentProps<typeof CriticalAlert>;
export { InfoAlert, PositiveAlert, WarningAlert, CriticalAlert };
