import "./Alert.css";
import { CheckIcon, InfoIcon, NotificationIcon, WarningIcon } from "../../icons";
import { useMemo } from "react";
import { Content } from "../../placeholders";
import { CrossButton } from "../../button";
import { StyleProvider, cssModule, forwardRef, mergeProps, useMergedRefs, useSlots } from "../../shared";
import { Text } from "../../text";
import { Transition } from "../../transition";
import { isNil } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const Role = {
  info: "status",
  positive: "status",
  warning: "alert",
  critical: "alert"
};
const AlertContent = forwardRef(({
  as = "div",
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/_jsx(Text, { ...rest,
    as: as,
    ref: ref,
    children: /*#__PURE__*/_jsx(StyleProvider, {
      value: {
        link: {
          color: "inherit",
          underline: "dotted"
        },
        heading: {
          size: "2xs",
          className: "o-ui-alert-title"
        }
      },
      children: children
    })
  });
});
export function InnerAlert({
  show = true,
  tone = "info",
  onDismiss,
  role: roleProp,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  var _ref;

  const ref = useMergedRefs(forwardedRef);
  const {
    icon,
    content,
    button
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Content
    },
    icon: {
      className: "o-ui-alert-icon"
    },
    content: {
      className: "o-ui-alert-content",
      as: AlertContent
    },
    button: {
      variant: "ghost",
      color: "inherit",
      condensed: true,
      size: "sm",
      className: "o-ui-alert-action"
    }
  }), []));

  const dismissMarkup = !isNil(onDismiss) && /*#__PURE__*/_jsx(CrossButton, {
    color: "inherit",
    onClick: onDismiss,
    size: "sm",
    className: "o-ui-alert-dismiss",
    "aria-label": "Dismiss"
  });

  return /*#__PURE__*/_jsxs(Transition, { ...mergeProps(rest, {
      show,
      enter: "o-ui-fade-in",
      leave: "o-ui-fade-out",
      className: cssModule("o-ui-alert", tone, icon && "has-icon", button && "has-action", dismissMarkup && "has-dismiss"),
      role: (_ref = roleProp !== null && roleProp !== void 0 ? roleProp : Role[tone]) !== null && _ref !== void 0 ? _ref : "alert",
      as,
      ref
    }),
    children: [icon, content, button, dismissMarkup]
  });
}
export const Alert = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAlert, { ...props,
  forwardedRef: ref
}));
Alert.displayName = "Alert"; ////////

const variations = [{
  tone: "info",
  icon: /*#__PURE__*/_jsx(NotificationIcon, {})
}, {
  tone: "positive",
  icon: /*#__PURE__*/_jsx(CheckIcon, {})
}, {
  tone: "warning",
  icon: /*#__PURE__*/_jsx(WarningIcon, {})
}, {
  tone: "critical",
  icon: /*#__PURE__*/_jsx(InfoIcon, {})
}];
const [InfoAlert, PositiveAlert, WarningAlert, CriticalAlert] = Object.values(variations).map(({
  tone,
  icon
}) => {
  return forwardRef(({
    children,
    ...rest
  }, ref) => {
    const {
      content,
      button
    } = useSlots(children, useMemo(() => ({
      _: {
        defaultWrapper: Content
      },
      content: null,
      button: null
    }), []));
    return /*#__PURE__*/_jsxs(Alert, {
      tone: tone,
      ...rest,
      ref: ref,
      children: [icon, content, button]
    });
  });
});
// Dummy component for documentation purpose.
// eslint-disable-next-line @typescript-eslint/no-unused-vars
export function AlertTemplate(_props) {
  return null;
}
InfoAlert.displayName = "InfoAlert";
PositiveAlert.displayName = "PositiveAlert";
WarningAlert.displayName = "WarningAlert";
CriticalAlert.displayName = "CriticalAlert";
export { InfoAlert, PositiveAlert, WarningAlert, CriticalAlert };