import "./TextButton.css";
import { ComponentProps, ElementType, ForwardedRef, MouseEventHandler, ReactNode } from "react";
import { InteractionStatesProps } from "../../shared";
interface InnerButtonProps extends InteractionStatesProps {
    /**
     * The button style to use.
     */
    variant?: "solid" | "outline" | "ghost";
    /**
     * The button color accent.
     */
    color?: "primary" | "secondary" | "danger" | "inherit";
    /**
     * The button shape.
     */
    shape?: "pill" | "rounded" | "circular";
    /**
     * Whether or not the button content should takes additional space.
     */
    condensed?: boolean;
    /**
     * Whether or not the button should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the button take up the width of its container.
     */
    fluid?: boolean;
    /**
     * A button can show a loading indicator.
     */
    loading?: boolean;
    /**
     * A button can vary in size.
     */
    size?: "sm" | "md";
    /**
     * Whether or not the button is disabled.
     */
    disabled?: boolean;
    /**
     * The button type.
     */
    type?: "button" | "submit" | "reset";
    /**
    * Called when the button is click.
    */
    onClick?: MouseEventHandler<HTMLElement>;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * Default slot override.
     */
    slot?: string;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerButton(props: InnerButtonProps): JSX.Element;
export declare const Button: import("../../shared").OrbitComponent<"button", InnerButtonProps>;
export declare type ButtonProps = ComponentProps<typeof Button>;
export {};
