import "./TextButton.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { createSizeAdapter, cssModule, forwardRef, mergeProps, omitProps, slot, useSlots } from "../../shared";
import { Text } from "../../text";
import { embeddedIconSize } from "../../icons";
import { useButton } from "./useButton";
import { useFormButton } from "../../form";
import { useToolbarProps } from "../../toolbar";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
const condensedTextSize = createSizeAdapter({
  "sm": "md",
  "md": "lg"
});
export function InnerButton(props) {
  const [formProps] = useFormButton();
  const [toolbarProps] = useToolbarProps();
  const {
    variant = "solid",
    color,
    shape = "pill",
    condensed,
    autoFocus,
    disabled,
    fluid,
    loading,
    size,
    active,
    focus,
    hover,
    type = "button",
    as = "button",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, formProps, omitProps(toolbarProps, ["orientation"]));
  const {
    ref: buttonRef,
    ...buttonProps
  } = useButton({
    cssModule: "o-ui-text-button",
    variant,
    color,
    shape,
    autoFocus,
    fluid,
    loading,
    size,
    active,
    focus,
    hover,
    type,
    forwardedRef
  });
  const {
    icon,
    text,
    "end-icon": endIcon,
    counter
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    icon: {
      size: condensed ? size : embeddedIconSize(size),
      className: "o-ui-button-icon o-ui-button-start-icon"
    },
    text: {
      size: condensed ? condensedTextSize(size) : size,
      className: "o-ui-button-text",
      "aria-hidden": loading
    },
    "end-icon": {
      size: condensed ? size : embeddedIconSize(size),
      className: "o-ui-button-end-icon"
    },
    counter: {
      size: condensed ? condensedTextSize(size) : size,
      color: "inherit",
      pushed: true,
      disabled,
      className: "o-ui-button-counter"
    }
  }), [size, disabled, condensed, loading]));
  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      disabled,
      className: cssModule("o-ui-button", icon && "has-start-icon", endIcon && "has-end-icon"),
      as,
      ref: buttonRef
    }, buttonProps),
    children: [icon, text, counter, endIcon]
  });
}
export const Button = slot("button", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerButton, { ...props,
  forwardedRef: ref
})));
Button.displayName = "Button";