import "./ButtonGroup.css";
import { Children } from "react";
import { Group } from "../../group";
import { augmentElement, cssModule, forwardRef, mergeProps, normalizeSize, omitProps, slot } from "../../shared";
import { useFieldInputProps } from "../../field";
import { jsx as _jsx } from "react/jsx-runtime";
const Gap = {
  "horizontal": {
    "sm": 3,
    "md": 4
  },
  "vertical": {
    "sm": 2,
    "md": 3
  }
};
export function InnerButtonGroup(props) {
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    orientation = "horizontal",
    align,
    size,
    fluid,
    disabled,
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, omitProps(fieldProps, ["fluid"]));
  return /*#__PURE__*/_jsx(Group, { ...mergeProps(rest, {
      orientation,
      align,
      verticalAlign: orientation === "horizontal" ? "center" : undefined,
      fluid,
      gap: Gap[orientation][normalizeSize(size)],
      className: cssModule("o-ui-button-group", isInField && "as-field"),
      role: !isInField ? "group" : undefined,
      ref: forwardedRef
    }),
    children: Children.map(children, x => {
      return augmentElement(x, {
        size,
        fluid,
        disabled
      });
    })
  });
}
export const ButtonGroup = slot("button-group", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerButtonGroup, { ...props,
  forwardedRef: ref
})));
ButtonGroup.displayName = "ButtonGroup";