import { AriaLabelingProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, SyntheticEvent } from "react";
interface InnerCrossButtonProps extends AriaLabelingProps {
    /**
     * Whether or not the button content should takes additional space.
     */
    condensed?: boolean;
    /**
     * Whether or not the button should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * A cross button can vary in size.
     */
    size?: "2xs" | "xs" | "sm" | "md";
    /**
     * Whether or not the cross button is disabled.
     */
    disabled?: boolean;
    /**
     * Called when the button is click.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onClick?: (event: SyntheticEvent) => void;
    /**
     * A label providing an accessible name to the button. See [WCAG](https://www.w3.org/TR/WCAG20-TECHS/ARIA14.html).
     */
    "aria-label": string;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * Default slot override.
     */
    slot?: string;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerCrossButton({ forwardedRef, ...rest }: InnerCrossButtonProps): JSX.Element;
export declare const CrossButton: import("../../shared").OrbitComponent<"button", InnerCrossButtonProps>;
export declare type CrossButtonProps = ComponentProps<typeof CrossButton>;
export {};
