import "./IconButton.css";
import { Box } from "../../box";
import { Children } from "react";
import { EmbeddedIcon } from "../../icons";
import { augmentElement, createEmbeddableAdapter, forwardRef, mergeProps, omitProps, slot } from "../../shared";
import { useButton } from "./useButton";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerIconButton(props) {
  const [toolbarProps] = useToolbarProps();
  const {
    variant = "solid",
    color,
    shape = "circular",
    condensed,
    autoFocus,
    fluid,
    loading,
    size,
    active,
    focus,
    hover,
    type = "button",
    title,
    "aria-label": ariaLabel,
    as = "button",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, omitProps(toolbarProps, ["orientation"]));
  const buttonProps = useButton({
    cssModule: "o-ui-icon-button",
    variant,
    color,
    shape,
    autoFocus,
    fluid,
    loading,
    size,
    active,
    focus,
    hover,
    type,
    forwardedRef
  });
  const icon = Children.only(children);
  const iconMarkup = augmentElement(condensed ? icon : /*#__PURE__*/_jsx(EmbeddedIcon, {
    children: icon
  }), {
    size,
    className: "o-ui-button-icon"
  });
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      title: title !== null && title !== void 0 ? title : ariaLabel,
      as,
      "aria-label": ariaLabel
    }, buttonProps),
    children: iconMarkup
  });
}
export const IconButton = slot("button", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerIconButton, { ...props,
  forwardedRef: ref
})));
IconButton.displayName = "IconButton";
export const embedIconButton = createEmbeddableAdapter({
  "sm": "2xs",
  "md": "xs"
});