import { isNil } from "lodash";
import { useControllableState, useEventCallback } from "../../shared";
//TODO: TS We had to have a shape be generic, since Toggle Button and ToggleIconButton don't have the same shape allowed.
// We want to preserve in the output type the same type as the one in the input props.
export function useToggleButton({
  variant,
  shape,
  checked,
  defaultChecked,
  value,
  onChange,
  onCheck,
  active,
  forwardedRef
}) {
  const [isChecked, setIsChecked] = useControllableState(checked, defaultChecked, false);
  const handleClick = useEventCallback(event => {
    setIsChecked(!isChecked);

    if (!isNil(onCheck)) {
      onCheck(event, value);
    }

    if (!isNil(onChange)) {
      onChange(event, !isChecked);
    }
  });
  return {
    isChecked,
    buttonProps: {
      variant,
      shape,
      onClick: handleClick,
      value,
      active: active || isChecked,
      "aria-checked": isChecked,
      ref: forwardedRef
    }
  };
}