import "./CheckboxGroup.css";
import { ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
export interface InnerCheckboxGroupProps {
    /**
   * The value of the checkbox group.
   */
    value?: string[];
    /**
     * The initial value of `value`.
     */
    defaultValue?: string[];
    /**
     * Whether a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether the group should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * Called when any of the children is checked or unchecked..
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {string[]} value - The new value.
     * @returns {void}
     */
    onChange?: (event: SyntheticEvent, value: string[]) => void;
    /**
     * Whether or not the first checkbox of the group should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * The orientation of the group elements.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * The space between the group elements.
     */
    gap?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | string;
    /**
     * Whether the group elements are forced onto one line or can wrap onto multiple lines
     */
    wrap?: boolean;
    /**
     * The group elements size.
     */
    size?: "sm" | "md";
    /**
     * Whether or not the group elements are disabled.
     */
    disabled?: boolean;
    /**
     * Invert the order of the checkbox and his label.
     */
    reverse?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerCheckboxGroup(props: InnerCheckboxGroupProps): JSX.Element;
export declare const CheckboxGroup: import("../../shared").OrbitComponent<HTMLElement, InnerCheckboxGroupProps>;
