import "./CheckboxGroup.css";
import { CheckableContext, augmentElement, forwardRef, mergeProps, omitProps, resolveChildren, useAutoFocusChild, useControllableState, useEventCallback, useFocusManager, useFocusScope, useMergedRefs } from "../../shared";
import { Children } from "react";
import { ClearFieldContext, useFieldInputProps } from "../../field";
import { ClearToolbar, useToolbarProps } from "../../toolbar";
import { Group } from "../../group";
import { isNil, isNumber } from "lodash";
import { useGroupInput } from "../../input";
import { jsx as _jsx } from "react/jsx-runtime";

function arrayToggleValue(array, value) {
  if (isNil(array)) {
    return [value];
  }

  const index = array.indexOf(value);

  if (index !== -1) {
    const newArray = [...array];
    newArray.splice(index, 1);
    return newArray;
  }

  return [...array, value];
}

export function InnerCheckboxGroup(props) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    value,
    defaultValue,
    required,
    validationState,
    onChange,
    autoFocus,
    orientation = "horizontal",
    gap,
    wrap,
    size,
    reverse,
    disabled,
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, toolbarProps, omitProps(fieldProps, ["fluid"]));
  const [checkedValue, setCheckedValue] = useControllableState(value, defaultValue, []);
  const [focusScope, setFocusRef] = useFocusScope();
  const groupRef = useMergedRefs(setFocusRef, forwardedRef);
  const focusManager = useFocusManager(focusScope);
  useAutoFocusChild(focusManager, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const {
    groupProps,
    itemProps
  } = useGroupInput({
    cssModule: "o-ui-checkbox-group",
    required,
    validationState,
    orientation,
    gap,
    wrap,
    size,
    reverse,
    disabled,
    isInField,
    groupRef
  });
  const handleCheck = useEventCallback((event, newValue) => {
    const newCheckedValue = arrayToggleValue(checkedValue, newValue);
    setCheckedValue(newCheckedValue);

    if (!isNil(onChange)) {
      onChange(event, newCheckedValue);
    }
  });
  const items = resolveChildren(children, {
    checkedValue
  });
  return /*#__PURE__*/_jsx(Group, { ...mergeProps(rest, groupProps),
    children: /*#__PURE__*/_jsx(ClearToolbar, {
      children: /*#__PURE__*/_jsx(ClearFieldContext, {
        children: /*#__PURE__*/_jsx(CheckableContext.Provider, {
          value: {
            onCheck: handleCheck,
            checkedValue
          },
          children: Children.map(items, x => {
            return augmentElement(x, { ...itemProps,
              role: "checkbox"
            });
          })
        })
      })
    })
  });
}
export const CheckboxGroup = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerCheckboxGroup, { ...props,
  forwardedRef: ref
}));
CheckboxGroup.displayName = "CheckboxGroup";