import "./DateRangeInput.css";
import { ComponentProps, ElementType, ForwardedRef, SyntheticEvent } from "react";
import { InteractionStatesProps } from "../../shared";
export interface DatePreset {
    text: string;
    startDate: Date;
    endDate: Date;
}
export interface InnerDateRangeInputProps extends InteractionStatesProps {
    name?: string;
    /**
     * A controlled start date value.
     */
    startDate?: Date;
    /**
     * A controlled end date value.
     */
    endDate?: Date;
    /**
     * The initial value of start date.
     */
    defaultStartDate?: Date;
    /**
     * The initial value of end date.
     */
    defaultEndDate?: Date;
    /**
     * Temporary text that occupies both date inputs when they are empty.
     */
    placeholder?: string;
    /**
     * The minimum (inclusive) date.
     */
    minDate?: Date;
    /**
     * The maximum (inclusive) date.
     */
    maxDate?: Date;
    /**
     * Whether or not a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether or not the input should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * Called when the date(s) are / is applied.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {Object} startDate - Selected start date.
     * @param {Object} endDate - Selected end date.
     * @returns {void}
     */
    onDatesChange?: (event: SyntheticEvent, startDate: Date, endDate: Date) => void;
    /**
     * Array of pre-determined dates range.
     */
    presets?: DatePreset[];
    /**
     * Whether or not the input should autofocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the input take up the width of its container.
     */
    fluid?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * Whether or not the input is readonly.
     */
    readOnly?: boolean;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerDateRangeInput(props: InnerDateRangeInputProps): JSX.Element;
export declare const DateRangeInput: import("../../shared").OrbitComponent<HTMLElement, InnerDateRangeInputProps>;
export declare type DateRangeInputProps = ComponentProps<typeof DateRangeInput>;
