// Must disable it for now because of the react-docgen hack.

/* eslint-disable react/no-unused-prop-types */
import "./DateRangeInput.css";
import { Box } from "../../box";
import { CalendarIcon, VerticalDotsIcon } from "../../icons";
import { useCallback, useRef, useState } from "react";
import { CrossButton, IconButton } from "../../button";
import { Divider } from "../../divider";
import { Keys, augmentElement, cssModule, forwardRef, mergeProps, omitProps, useAutoFocus, useControllableState, useEventCallback, useMergedRefs } from "../../shared";
import { Item } from "../../collection";
import { Menu, MenuTrigger } from "../../menu";
import { isNil, isNumber } from "lodash";
import { useDateInput } from "./useDateInput";
import { useFieldInputProps } from "../../field";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
const DateInput = forwardRef(({
  value,
  placeholder,
  required,
  validationState,
  minDate,
  maxDate,
  onChange,
  onDateChange,
  autoFocus,
  disabled,
  readOnly,
  ...rest
}, ref) => {
  const inputRef = useMergedRefs(ref);
  useAutoFocus(inputRef, {
    isDisabled: !autoFocus || disabled || readOnly,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const dateProps = useDateInput({
    value,
    minDate,
    maxDate,
    onChange,
    onDateChange,
    forwardedRef: inputRef
  });
  return /*#__PURE__*/_jsx("input", { ...mergeProps(rest, {
      placeholder,
      className: "o-ui-date-range-input-date-input",
      type: "text",
      disabled,
      readOnly,
      "aria-required": required ? true : undefined,
      "aria-invalid": validationState === "invalid" ? true : undefined,
      ref: inputRef
    }, dateProps)
  });
});
export function InnerDateRangeInput(props) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    startDate: startDateProp,
    endDate: endDateProp,
    defaultStartDate,
    defaultEndDate,
    placeholder,
    minDate,
    maxDate,
    required,
    validationState,
    onDatesChange,
    presets,
    autoFocus,
    fluid,
    disabled,
    readOnly,
    active,
    focus = false,
    hover,
    name,
    as = "div",
    forwardedRef,
    ...rest
  } = mergeProps(props, omitProps(toolbarProps, ["orientation"]), fieldProps);
  const [startDate, setStartDate] = useControllableState(startDateProp, defaultStartDate, null);
  const [endDate, setEndDate] = useControllableState(endDateProp, defaultEndDate, null);
  const [hasFocus, setHasFocus] = useState(focus);
  const startDateRef = useRef();
  const endDateRef = useRef();
  const applyDates = useCallback((event, newStartDate, newEndDate) => {
    if (startDate !== newStartDate || endDate !== newEndDate) {
      if (!isNil(onDatesChange)) {
        onDatesChange(event, newStartDate, newEndDate);
      }

      setStartDate(newStartDate);
      setEndDate(newEndDate);
    }
  }, [onDatesChange, startDate, setStartDate, endDate, setEndDate]);
  const handleStartDateChange = useEventCallback((event, newDate) => {
    if (!isNil(newDate) && !isNil(endDate) && newDate > endDate) {
      newDate = endDate;
    }

    applyDates(event, newDate, endDate);

    if (!isNil(newDate)) {
      // Jump to end date.
      endDateRef === null || endDateRef === void 0 ? void 0 : endDateRef.current.focus();
    }
  });
  const handleEndDateInputValueChange = useEventCallback(event => {
    if (event.target.value === "") {
      // Jump to start date.
      startDateRef === null || startDateRef === void 0 ? void 0 : startDateRef.current.focus();
    }
  });
  const handleEndDateChange = useEventCallback((event, newDate) => {
    if (!isNil(newDate) && !isNil(startDate) && newDate < startDate) {
      newDate = startDate;
    }

    applyDates(event, startDate, newDate);
  });
  const handleDateFocus = useEventCallback(() => {
    setHasFocus(true);
  });
  const handleDateBlur = useEventCallback(() => {
    setHasFocus(false);
  });
  const handleSelectPreset = useEventCallback((event, key) => {
    const preset = presets[key];

    if (!isNil(preset)) {
      applyDates(event, preset.startDate, preset.endDate);
    }
  });
  const handleClearDates = useEventCallback(event => {
    applyDates(event, null, null);
    startDateRef === null || startDateRef === void 0 ? void 0 : startDateRef.current.focus();
  });
  const handleKeyDown = useEventCallback(event => {
    if (event.key === Keys.esc) {
      event.preventDefault();
      handleClearDates(event);
    }
  });
  const hasValue = !isNil(startDate) || !isNil(endDate);

  const inputMarkup = /*#__PURE__*/_jsxs(Box, {
    onKeyDown: handleKeyDown,
    className: cssModule("o-ui-date-range-input", validationState, fluid && "fluid", disabled && "disabled", readOnly && "readonly", active && "active", hasFocus && "focus", hover && "hover"),
    role: !isInField ? "group" : undefined,
    children: [/*#__PURE__*/_jsx(CalendarIcon, {
      className: "o-ui-date-range-input-icon"
    }), /*#__PURE__*/_jsx(DateInput, {
      value: startDate,
      placeholder: placeholder,
      required: required,
      validationState: validationState,
      minDate: minDate,
      onDateChange: handleStartDateChange,
      autoFocus: autoFocus,
      onFocus: handleDateFocus,
      onBlur: handleDateBlur,
      disabled: disabled,
      readOnly: readOnly,
      name: !isNil(name) ? `${name}-start-date` : undefined,
      ref: startDateRef
    }), /*#__PURE__*/_jsx(Divider, {
      orientation: "vertical",
      className: "o-ui-date-range-input-divider"
    }), /*#__PURE__*/_jsx(DateInput, {
      value: endDate,
      placeholder: placeholder,
      required: required,
      validationState: validationState,
      maxDate: maxDate,
      onChange: handleEndDateInputValueChange,
      onDateChange: handleEndDateChange,
      onFocus: handleDateFocus,
      onBlur: handleDateBlur,
      disabled: disabled,
      readOnly: readOnly,
      name: !isNil(name) ? `${name}-end-date` : undefined,
      tabIndex: hasFocus ? "0" : "-1",
      ref: endDateRef
    }), hasValue && !disabled && !readOnly && /*#__PURE__*/_jsx(CrossButton, {
      onClick: handleClearDates,
      size: "xs",
      condensed: true,
      className: "o-ui-date-range-input-clear-button",
      "aria-label": "Clear dates"
    })]
  });

  const presetsMarkup = !isNil(presets) && /*#__PURE__*/_jsxs(MenuTrigger, {
    children: [/*#__PURE__*/_jsx(IconButton, {
      shape: "rounded",
      color: "secondary",
      condensed: true,
      "aria-label": "Date presets",
      children: /*#__PURE__*/_jsx(VerticalDotsIcon, {})
    }), /*#__PURE__*/_jsx(Menu, {
      onSelectionChange: handleSelectPreset,
      children: presets.map((x, index) =>
      /*#__PURE__*/
      // eslint-disable-next-line react/no-array-index-key
      _jsx(Item, {
        children: x.text
      }, index.toString()))
    })]
  });

  const container = !isNil(presets) ? /*#__PURE__*/_jsxs(Box, {
    className: "o-ui-date-range-input-group",
    role: "presentation",
    children: [inputMarkup, presetsMarkup]
  }) : inputMarkup; // HACK: Returning the augmented element in a fragment to comply with react-docgen.

  return /*#__PURE__*/_jsx(_Fragment, {
    children: augmentElement(container, mergeProps(rest, {
      as,
      ref: forwardedRef
    }))
  });
}
export const DateRangeInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerDateRangeInput, { ...props,
  forwardedRef: ref
}));
DateRangeInput.displayName = "DateRangeInput";