import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
interface InnerDialogTriggerProps {
    /**
     * Whether or not to show the modal element.
     */
    open?: boolean;
    /**
     * The initial value of open when in auto controlled mode.
     */
    defaultOpen?: boolean;
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {boolean} isOpen - Indicate if the menu is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * Whether or not the modal should close on outside interactions.
     */
    dismissable?: boolean;
    /**
     * z-index of the modal.
     */
    zIndex?: number;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerDialogTrigger({ open: openProp, defaultOpen, onOpenChange, dismissable, zIndex, as, children, forwardedRef, ...rest }: InnerDialogTriggerProps): JSX.Element;
export declare const DialogTrigger: import("../../shared").OrbitComponent<HTMLElement, InnerDialogTriggerProps>;
export declare type DialogTriggerProps = ComponentProps<typeof DialogTrigger>;
export {};
