import { Children, useCallback } from "react";
import { DialogTriggerContext } from "./DialogTriggerContext";
import { Overlay, useOverlayLightDismiss, useOverlayTrigger } from "../../overlay";
import { augmentElement, forwardRef, mergeProps, resolveChildren, useControllableState, useEventCallback, useMergedRefs } from "../../shared";
import { isNil } from "lodash";
/*
TODO:
    - FocusTrap
    - I believe we need some way to hide the elements behind the underlay from screen readers.. See spectrum.
*/

import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerDialogTrigger({
  open: openProp,
  defaultOpen,
  onOpenChange,
  dismissable,
  zIndex = 1,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const [isOpen, setIsOpen] = useControllableState(openProp, defaultOpen, false);
  const modalRef = useMergedRefs(forwardedRef);
  const updateIsOpen = useCallback((event, newValue) => {
    if (!isNil(onOpenChange)) {
      onOpenChange(event, newValue);
    }

    setIsOpen(newValue);
  }, [onOpenChange, setIsOpen]);
  const open = useCallback(event => {
    updateIsOpen(event, true);
  }, [updateIsOpen]);
  const close = useCallback(event => {
    updateIsOpen(event, false);
  }, [updateIsOpen]);
  const [trigger, modal] = Children.toArray(resolveChildren(children, {
    close
  }));

  if (isNil(trigger) || isNil(modal)) {
    throw new Error("A modal trigger must have exactly 2 children.");
  }

  const triggerProps = useOverlayTrigger({
    isOpen,
    onShow: useEventCallback(event => {
      open(event);
    }),
    onHide: useEventCallback(event => {
      close(event);
    })
  }); // TODO: not sure it should use this hook, it's been designed for popups.

  const overlayDismissProps = useOverlayLightDismiss(modalRef, {
    onHide: useEventCallback(event => {
      updateIsOpen(event, false);
    }),
    hideOnEscape: isOpen,
    hideOnLeave: false,
    hideOnOutsideClick: isOpen && dismissable
  });
  const triggerMarkup = augmentElement(trigger, triggerProps);
  const modalMarkup = augmentElement(modal, {
    dismissable,
    zIndex: zIndex + 1,
    ref: modalRef
  });
  return /*#__PURE__*/_jsxs(DialogTriggerContext.Provider, {
    value: {
      isOpen,
      open,
      close
    },
    children: [triggerMarkup, /*#__PURE__*/_jsx(Overlay, { ...mergeProps(rest, {
        show: isOpen,
        zIndex,
        as
      }, overlayDismissProps),
      children: modalMarkup
    })]
  });
}
export const DialogTrigger = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerDialogTrigger, { ...props,
  forwardedRef: ref
}));
DialogTrigger.displayName = "DialogTrigger";