import "./Modal.css";
import { cssModule, forwardRef, mergeProps, useAutoFocus, useEventCallback, useId, useMergedRefs, useRefState, useResizeObserver, useSlots } from "../../shared";
import { Box } from "../../box";
import { useEffect, useMemo, useState } from "react";
import { Content } from "../../placeholders";
import { CrossButton } from "../../button";
import { Underlay } from "../../overlay";
import { isNil } from "lodash";
import { useDialogTriggerContext } from "./DialogTriggerContext";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";

function useHideBodyScrollbar() {
  const [stateRef, setState] = useRefState({
    isVisible: true,
    originalPosition: ""
  });
  useEffect(() => {
    if (stateRef.current.isVisible) {
      setState({
        isVisible: false,
        originalPosition: document.body.style.overflowY
      });
      document.body.style.overflowY = "hidden";
    }

    return () => {
      // eslint-disable-next-line react-hooks/exhaustive-deps
      const state = stateRef.current;

      if (!state.isVisible) {
        setState({
          isVisible: true,
          originalPosition: ""
        });
        document.body.style.overflowY = state.originalPosition;
      }
    };
  }, [stateRef, setState]);
}

function useElementHasVerticalScrollbar(element) {
  const [hasScrollbar, setHasScrollbar] = useState(false);
  const handleElementResize = useEventCallback(() => {
    setHasScrollbar(element.scrollHeight > element.clientHeight);
  });
  useResizeObserver(element, handleElementResize);
  return hasScrollbar;
}

export function InnerModal({
  id,
  dismissable,
  zIndex = 1,
  "aria-label": ariaLabel,
  "aria-labelledby": ariaLabelledBy,
  as = "div",
  wrapperProps,
  children,
  forwardedRef,
  ...rest
}) {
  var _heading$props;

  const [wrapperElement, setWrapperElement] = useState();
  const modalRef = useMergedRefs(forwardedRef);
  const {
    close
  } = useDialogTriggerContext();
  useHideBodyScrollbar();
  const wrapperHasVerticalScrollbar = useElementHasVerticalScrollbar(wrapperElement);
  useAutoFocus(modalRef);
  const handleCloseButtonClick = useEventCallback(event => {
    close(event);
  });
  const modalId = useId(id, id ? null : "o-ui-modal");
  const headingId = `${modalId}-heading`;
  const {
    heading,
    content
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Content
    },
    heading: {
      id: headingId,
      className: "o-ui-modal-heading"
    },
    content: {
      className: "o-ui-modal-content"
    }
  }), [headingId]));

  const closeButtonMarkup = dismissable && /*#__PURE__*/_jsx(CrossButton, {
    onClick: handleCloseButtonClick,
    condensed: true,
    size: "xs",
    className: "o-ui-modal-close-button",
    "aria-label": "Close"
  });

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Underlay, {
      zIndex: zIndex
    }), /*#__PURE__*/_jsx(Box, { ...mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
        className: cssModule("o-ui-modal-wrapper", wrapperHasVerticalScrollbar && "scrolling"),
        style: {
          zIndex: zIndex + 1
        },
        as,
        ref: setWrapperElement
      }),
      children: /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
          className: "o-ui-modal",
          tabIndex: -1,
          role: "dialog",
          "aria-modal": true,
          "aria-label": ariaLabel,
          "aria-labelledby": isNil(ariaLabel) ? ariaLabelledBy !== null && ariaLabelledBy !== void 0 ? ariaLabelledBy : heading === null || heading === void 0 ? void 0 : (_heading$props = heading.props) === null || _heading$props === void 0 ? void 0 : _heading$props.id : undefined,
          ref: modalRef
        }),
        children: [closeButtonMarkup, heading, content]
      })
    })]
  });
}
export const Modal = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerModal, { ...props,
  forwardedRef: ref
}));
Modal.displayName = "Modal";