import "./Disclosure.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { DomProps } from "../../shared";
export interface InnerDisclosureProps extends DomProps {
    /**
     * A controlled open value.
     */
    open?: boolean;
    /**
     * The initial value of `open` when uncontrolled.
     */
    defaultOpen?: boolean;
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {bool} isOpen - Whether or not the content is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerDisclosure({ id, open, defaultOpen, onOpenChange, as, children, forwardedRef, ...rest }: InnerDisclosureProps): JSX.Element;
export declare const Disclosure: import("../../shared").OrbitComponent<HTMLElement, InnerDisclosureProps>;
export declare type DisclosureProps = ComponentProps<typeof Disclosure>;
