import "./Dot.css";
import { Box } from "../../box";
import { Text } from "../../text";
import { cssModule, forwardRef, mergeProps, slot } from "../../shared";
import { isNil } from "lodash";
import { useMemo } from "react";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerDot(props) {
  const {
    color,
    as = "span",
    children,
    forwardedRef,
    ...rest
  } = props;

  const labelMarkup = children && /*#__PURE__*/_jsx(Text, {
    children: children
  });

  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-dot", children && "has-label"),
      style: {
        ["--o-ui-dot-color"]: useColor(color)
      },
      as,
      ref: forwardedRef
    }),
    children: labelMarkup
  });
}

function useColor(color) {
  return useMemo(() => {
    if (!isNil(color)) {
      if (color.startsWith("rgb") || color.startsWith("hsl") || color.startsWith("#")) {
        return color;
      } else if (color.startsWith("--")) {
        return `var(${color})`;
      } else {
        return `var(--o-ui-global-${color})`;
      }
    }
  }, [color]);
}

export const Dot = slot("dot", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerDot, { ...props,
  forwardedRef: ref
})));
Dot.displayName = "Dot";