import { createContext, useContext } from "react";
import { cssModule, normalizeSize } from "../../shared";
import { isNil } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
export const FieldContext = /*#__PURE__*/createContext(null);
export function useFieldContext() {
  const context = useContext(FieldContext);

  if (!isNil(context)) {
    const {
      isGroup = false,
      ...rest
    } = context;
    const props = { ...rest,
      isGroup
    };
    return [props, true];
  }

  return [{}, false];
}
export function useFieldLabelProps({
  as: asProp
}) {
  const [{
    isGroup,
    inputId,
    labelId,
    required,
    size,
    labelClassName
  }, isInField] = useFieldContext();
  const as = isNil(asProp) ? isGroup ? "span" : "label" : asProp;
  const props = isInField && {
    id: labelId,
    required,
    size,
    htmlFor: as === "label" ? inputId : undefined,
    className: cssModule(labelClassName, normalizeSize(size)),
    as
  };
  return [props || {}, isInField];
}
export function useFieldInputProps() {
  const [{
    isGroup,
    validationState,
    inputId,
    required,
    fluid,
    size,
    disabled,
    inputClassName
  }, isInField] = useFieldContext();
  const props = isInField && {
    validationState,
    id: !isGroup ? inputId : undefined,
    required,
    disabled,
    fluid,
    size,
    className: inputClassName
  };
  return [props || {}, isInField];
}
export function useFieldMessageProps() {
  const [{
    messageId,
    size,
    fluid,
    validationState,
    messageClassName
  }, isInField] = useFieldContext();
  const props = isInField && {
    id: messageId,
    size,
    fluid,
    validationState,
    className: cssModule(messageClassName, normalizeSize(size)),
    "aria-live": "polite"
  };
  return [props || {}, isInField];
}
export function ClearFieldContext({
  children
}) {
  return /*#__PURE__*/_jsx(FieldContext.Provider, {
    value: null,
    children: children
  });
}