import "./Image.css";
import { ComponentProps, ElementType, ForwardedRef } from "react";
export interface InnerImageProps {
    /**
     * The path to the image.
     */
    src: string;
    /**
     * A text description of the image.
     */
    alt: string;
    /**
     * Width and height in a single value.
     */
    size?: string;
    /**
    * @ignore
    */
    width?: number;
    /**
    * @ignore
    */
    height?: number;
    /**
     * The image shape.
     */
    shape?: "rounded" | "circular";
    /**
     * How the image should be resized to fit its container. See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit).
     */
    fit?: "contain" | "cover" | "fill" | "scale-down" | "none";
    /**
     * The alignment of the image within it's box. See [MDN](https://developer.mozilla.org/en-US/docs/Web/CSS/object-position).
     */
    position?: string;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerImage({ shape, size, width, height, fit, position, as: As, forwardedRef, ...rest }: InnerImageProps): JSX.Element;
export declare const Image: import("../../shared").OrbitComponent<HTMLElement, InnerImageProps>;
export declare type ImageProps = ComponentProps<typeof Image>;
