import "./Flex.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { cssModule, forwardRef, isNilOrEmpty, mergeProps } from "../../shared";
import { isNil, isString } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
const Spacing = ["--o-ui-global-scale-alpha", "--o-ui-global-scale-bravo", "--o-ui-global-scale-charlie", "--o-ui-global-scale-delta", "--o-ui-global-scale-echo", "--o-ui-global-scale-foxtrot", "--o-ui-global-scale-golf", "--o-ui-global-scale-hotel", "--o-ui-global-scale-india", "--o-ui-global-scale-juliett", "--o-ui-global-scale-kilo", "--o-ui-global-scale-lima", "--o-ui-global-scale-mike"];
let globalIsGapSupported = undefined; // @supports doesn't work for flexbox-gap.

function useIsGapSupported(noGap) {
  return useMemo(() => {
    if (noGap) {
      return false;
    }

    if (!isNil(globalIsGapSupported)) {
      return globalIsGapSupported;
    }

    const element = document.createElement("DIV");
    element.innerHTML = `
            <div id="o-ui-flex-gap-support" style="display: inline-flex; gap: 1px; visibility: hidden">
                <div style="width: 1px"></div>
                <div style="width: 1px"></div>
            </div>
        `;
    document.body.appendChild(element);
    const width = document.getElementById("o-ui-flex-gap-support").clientWidth;
    document.body.removeChild(element);
    globalIsGapSupported = width === 3;
    return globalIsGapSupported;
  }, [noGap]);
}

export function InnerFlex({
  direction,
  inline,
  reverse,
  alignContent,
  alignItems,
  justifyContent,
  gap,
  wrap,
  fluid,
  children,
  forwardedRef,
  ...rest
}) {
  const noGap = isNilOrEmpty(gap) || gap === 0;
  const isGapSupported = useIsGapSupported(noGap);
  const items = children;
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-flex", direction || "row", inline && "inline", reverse && "reverse", fluid && "fluid", !isGapSupported && "no-gap"),
      style: {
        flexDirection: direction ? `${direction}${reverse ? "-reverse" : ""}` : undefined,
        // Normalize values until Chrome support `start` & `end`, https://developer.mozilla.org/en-US/docs/Web/CSS/align-items.
        alignContent: alignContent && alignContent.replace("start", "flex-start").replace("end", "flex-end"),
        alignItems: alignItems && alignItems.replace("start", "flex-start").replace("end", "flex-end"),
        justifyContent: justifyContent && justifyContent.replace("start", "flex-start").replace("end", "flex-end"),
        flexWrap: !isNil(wrap) ? "wrap" : undefined,
        ["--o-ui-flex-gap"]: !noGap && (isString(gap) ? gap : `var(${Spacing[gap - 1]})`)
      },
      ref: forwardedRef
    }),
    children: items
  });
}
export const Flex = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerFlex, { ...props,
  forwardedRef: ref
}));