import "./Link.css";
import { AriaLabelingProps, InteractionStatesProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerIconLinkProps extends InteractionStatesProps, AriaLabelingProps {
    /**
     * The URL that the link points to. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    href?: string;
    /**
     * Where to display the linked URL, as the name for a browsing context (a tab, window, or iframe). See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    target?: string;
    /**
     * The relationship of the linked URL as space-separated link types. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    rel?: string;
    /**
     * The link color accent.
     */
    color?: "primary" | "secondary" | "danger";
    /**
     * Whether or not the link content should takes additional space.
     */
    condensed?: boolean;
    /**
     * Whether or not this is an external link.
     */
    external?: boolean;
    /**
     * Whether or not the link should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * A link can vary in size.
     */
    size?: "sm" | "md";
    /**
     * Whether or not the link is disabled.
     */
    disabled?: boolean;
    /**
     * A label providing an accessible name to the button. See [WCAG](https://www.w3.org/TR/WCAG20-TECHS/ARIA14.html).
     */
    "aria-label": string;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
    * @ignore
    */
    title?: string;
    /**
    * @ignore
    */
    visited?: boolean;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerIconLink(props: InnerIconLinkProps): JSX.Element;
export declare const IconLink: import("../../shared").OrbitComponent<HTMLElement, InnerIconLinkProps>;
export declare type IconLinkProps = ComponentProps<typeof IconLink>;
