import "./Link.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerLinkProps {
    /**
     * The URL that the link points to. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    href?: string;
    /**
     * Where to display the linked URL, as the name for a browsing context (a tab, window, or iframe). See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    target?: string;
    /**
     * The relationship of the linked URL as space-separated link types. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    rel?: string;
    /**
     * Whether or not this is an external link.
     */
    external?: boolean;
    /**
     * The link shape.
     */
    shape?: "rounded" | "circular" | "box";
    /**
     * Whether or not the link should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the link is disabled.
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerLink(props: InnerLinkProps): JSX.Element;
export declare const Link: import("../../shared").OrbitComponent<HTMLElement, InnerLinkProps>;
export declare type LinkProps = ComponentProps<typeof Link>;
