import "./Link.css";
import { ComponentProps, ElementType, ForwardedRef, ReactElement } from "react";
export interface InnerTextLinkProps {
    /**
     * The URL that the link points to. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    href?: string;
    /**
     * Where to display the linked URL, as the name for a browsing context (a tab, window, or iframe). See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    target?: string;
    /**
     * The relationship of the linked URL as space-separated link types. See [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a).
     */
    rel?: string;
    /**
     * The color accent.
     */
    color?: "primary" | "secondary" | "danger" | "inherit";
    /**
     * The underline style.
     */
    underline?: "solid" | "dotted";
    /**
     * Whether or not this is an external link.
     */
    external?: boolean;
    /**
     * Whether or not the link should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * A link can vary in size.
     */
    size?: "sm" | "md" | "inherit";
    /**
     * @ignore
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactElement<any, any>;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerTextLink(props: InnerTextLinkProps): JSX.Element;
export declare const TextLink: import("../../shared").OrbitComponent<HTMLElement, InnerTextLinkProps>;
export declare type TextLinkProps = ComponentProps<typeof TextLink>;
