import "./Link.css";
import { ArrowIcon, embeddedIconSize } from "../../icons";
import { useMemo } from "react";
import { Text } from "../../text";
import { augmentElement, forwardRef, mergeProps, useSlots, useStyleProps } from "../../shared";
import { useFormButton } from "../../form";
import { useLink } from "./useLink";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerTextLink(props) {
  const [styleProps] = useStyleProps("link");
  const [formProps] = useFormButton();
  const {
    target,
    rel,
    color,
    underline,
    external,
    autoFocus,
    size,
    active,
    focus,
    hover,
    visited,
    as: As = "a",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, styleProps, formProps);
  const linkProps = useLink({
    cssModule: "o-ui-text-link",
    color,
    underline,
    external,
    autoFocus,
    active,
    focus,
    hover,
    visited,
    target,
    rel,
    forwardedRef
  });
  const {
    "start-icon": startIcon,
    text,
    icon
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    "start-icon": {
      size: embeddedIconSize(size),
      className: "o-ui-link-start-icon"
    },
    text: {
      size,
      className: "o-ui-link-text"
    },
    icon: null
  }), [size]));
  const iconElement = external ? /*#__PURE__*/_jsx(ArrowIcon, {}) : icon;
  const iconMarkup = iconElement && augmentElement(iconElement, {
    size: embeddedIconSize(size),
    className: "o-ui-link-end-icon"
  });
  return /*#__PURE__*/_jsxs(As, { ...mergeProps(rest, linkProps),
    children: [startIcon, text, iconMarkup]
  });
}
export const TextLink = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTextLink, { ...props,
  forwardedRef: ref
}));
TextLink.displayName = "TextLink";