import "./Menu.css";
import { AriaLabelingProps, DomProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import type { SelectionMode } from "./selectionMode";
export declare const ItemKeyProp = "data-o-ui-key";
export interface InnerMenuProps extends DomProps, AriaLabelingProps {
    /**
     * A controlled set of the selected item keys.
     */
    selectedKeys?: string[];
    /**
     * The initial value of `selectedKeys` when uncontrolled.
     */
    defaultSelectedKeys?: string[];
    /**
     * Called when the selected keys change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {String[]} keys - The keys of the selected items..
     * @returns {void}
     */
    onSelectionChange?: (event: SyntheticEvent, keys: string[]) => void;
    /**
     * The type of selection that is allowed.
     */
    selectionMode?: SelectionMode;
    /**
     * Whether or not the menu should autofocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Default focus target when enabling autofocus.
     */
    defaultFocusTarget?: string;
    /**
     * Whether or not the listbox take up the width of its container.
     */
    fluid?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerMenu({ id, selectedKeys: selectedKeysProp, defaultSelectedKeys, onSelectionChange, selectionMode, autoFocus, defaultFocusTarget, fluid, "aria-label": ariaLabel, "aria-labelledby": ariaLabelledBy, as, children, forwardedRef, ...rest }: InnerMenuProps): JSX.Element;
export declare const Menu: import("../../shared").OrbitComponent<HTMLElement, InnerMenuProps>;
export declare type MenuProps = ComponentProps<typeof Menu>;
