import { ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { DomProps } from "../../shared";
export interface InnerMenuTriggerProps extends DomProps {
    /**
     * Whether or not to show the menu.
     */
    open?: boolean;
    /**
     * The initial value of open when in auto controlled mode.
     */
    defaultOpen?: boolean;
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {boolean} isOpen - Indicate if the menu is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * Whether or not the menu should close when an item is selected.
     */
    closeOnSelect?: boolean;
    /**
     * The direction the menu will open relative to the trigger.
     */
    direction?: "bottom" | "top";
    /**
     * The horizontal alignment of the menu relative to the trigger.
     */
    align?: "start" | "end";
    /**
     * Whether or not the menu can flip when it will overflow it's boundary area.
     */
    allowFlip?: boolean;
    /**
     * Whether or not the menu position can change to prevent it from being cut off so that it stays visible within its boundary area.
     */
    allowPreventOverflow?: boolean;
    /**
     * z-index of the menu.
     */
    zIndex?: number;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerMenuTrigger({ id, open: openProp, defaultOpen, onOpenChange, closeOnSelect, direction, align, allowFlip, allowPreventOverflow, zIndex, as, children, forwardedRef, ...rest }: InnerMenuTriggerProps): JSX.Element;
export declare const MenuTrigger: import("../../shared").OrbitComponent<HTMLElement, InnerMenuTriggerProps>;
