import "./Overlay.css";
import { ThemeProvider } from "../../theme-provider/src/ThemeProvider";
import { Transition } from "../../transition";
import { createPortal } from "react-dom";
import { cssModule, forwardRef, mergeProps } from "../../shared";
import { useThemeContext } from "../../theme-provider";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
export function InnerOverlay({
  show,
  borderOffset,
  containerElement,
  zIndex,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  // Since the overlay is rendered through a portal it might not be embedded in the theme DOM element.
  const {
    theme,
    colorScheme
  } = useThemeContext();

  const content = /*#__PURE__*/_jsx(ThemeProvider, {
    theme: theme,
    colorScheme: colorScheme,
    children: /*#__PURE__*/_jsx(Transition, { ...mergeProps(rest, {
        show,
        enter: "o-ui-fade-in",
        leave: "o-ui-fade-out",
        className: cssModule("o-ui-overlay", borderOffset && "has-border-offset"),
        style: {
          "--o-ui-overlay-border-offset": borderOffset,
          zIndex
        },
        as,
        ref: forwardedRef
      }),
      children: children
    })
  }); // A fragment is wrapping the result to make this component work with react-docgen: https://github.com/reactjs/react-docgen/issues/336


  return /*#__PURE__*/_jsx(_Fragment, {
    children: /*#__PURE__*/createPortal(content, containerElement || document.body)
  });
}
export const Overlay = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerOverlay, { ...props,
  forwardedRef: ref
}));
Overlay.displayName = "Overlay";