import "./Popover.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { Text } from "../../text";
import { forwardRef, mergeProps, useSlots } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerPopover({
  as = "section",
  children,
  forwardedRef,
  ...rest
}) {
  const {
    heading,
    content,
    footer,
    button,
    "button-group": buttonGroup
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["heading", "content"]
    },
    heading: {
      size: "sm",
      as: "h1"
    },
    content: {
      className: "o-ui-popover-content",
      role: "dialog",
      as: Text
    },
    footer: {
      className: "o-ui-popover-footer-text",
      as: Text
    },
    button: {
      className: "o-ui-popover-button",
      size: "sm"
    },
    "button-group": {
      className: "o-ui-popover-button-group",
      size: "sm"
    }
  }), []));

  const headerMarkup = heading && /*#__PURE__*/_jsx("header", {
    className: "o-ui-popover-header",
    children: heading
  });

  const footerMarkup = (button || buttonGroup || footer) && /*#__PURE__*/_jsxs("footer", {
    className: "o-ui-popover-footer",
    children: [footer, button, buttonGroup]
  });

  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      className: "o-ui-popover",
      as,
      ref: forwardedRef
    }),
    children: [headerMarkup, content, footerMarkup]
  });
}
export const Popover = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerPopover, { ...props,
  forwardedRef: ref
}));
Popover.displayName = "Popover";