import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { DomProps } from "../../shared";
export interface InnerPopoverTriggerProps extends DomProps {
    /**
     * Whether or not to show the popover.
     */
    open?: boolean;
    /**
     * The initial value of `open` when in auto controlled mode.
     */
    defaultOpen?: boolean;
    /**
     * The interaction that triggers the popover.
     */
    trigger?: "click" | "hover";
    /**
     * Position of the popover element related to the trigger.
     */
    position?: ("auto" | "auto-start" | "auto-end" | "top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end");
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {boolean} isOpen - Indicate if the popover is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * Whether or not the popover should close on outside interactions.
     */
    dismissable?: boolean;
    /**
     * Whether or not the popover element can flip when it will overflow it's boundary area.
     */
    allowFlip?: boolean;
    /**
     * Whether or not the popover element position can change to prevent it from being cut off so that it stays visible within its boundary area.
     */
    allowPreventOverflow?: boolean;
    /**
     * z-index of the popover element.
     */
    zIndex?: number;
    /**
     * A DOM element in which the overlay element will be appended via a React portal.
     */
    containerElement?: HTMLElement;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerPopoverTrigger({ id, open, defaultOpen, trigger: triggerProp, position: positionProp, onOpenChange, dismissable, allowFlip, allowPreventOverflow, containerElement, zIndex, as, children, forwardedRef, ...rest }: InnerPopoverTriggerProps): JSX.Element;
export declare const PopoverTrigger: import("../../shared").OrbitComponent<HTMLElement, InnerPopoverTriggerProps>;
export declare type PopoverTriggerProps = ComponentProps<typeof PopoverTrigger>;
