import { Children, useCallback } from "react";
import { augmentElement, forwardRef, mergeProps, resolveChildren, useAutoFocus, useMergedRefs } from "../../shared";
import { Overlay, OverlayArrow, usePopup } from "../../overlay";
import { PopoverTriggerContext } from "./PopoverTriggerContext";
import { isNil } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerPopoverTrigger({
  id,
  open,
  defaultOpen,
  trigger: triggerProp = "click",
  position: positionProp = "bottom",
  onOpenChange,
  dismissable = true,
  allowFlip = true,
  allowPreventOverflow = true,
  containerElement,
  zIndex = 10000,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const overlayRef = useMergedRefs(forwardedRef);
  const {
    isOpen,
    setIsOpen,
    triggerProps,
    overlayProps,
    arrowProps
  } = usePopup("dialog", {
    id,
    open,
    defaultOpen,
    onOpenChange,
    hideOnEscape: true,
    hideOnLeave: triggerProp === "hover" && dismissable,
    hideOnOutsideClick: dismissable,
    restoreFocus: true,
    trigger: triggerProp,
    hasArrow: true,
    position: positionProp,
    allowFlip,
    allowPreventOverflow,
    boundaryElement: containerElement
  });
  useAutoFocus(overlayRef, {
    isDisabled: !isOpen || triggerProp !== "click"
  });
  const close = useCallback(event => {
    setIsOpen(event, false);
  }, [setIsOpen]);
  const [trigger, popover] = Children.toArray(resolveChildren(children, {
    close
  }));

  if (isNil(trigger) || isNil(popover)) {
    throw new Error("A popover trigger must have exactly 2 children.");
  }

  const triggerMarkup = augmentElement(trigger, triggerProps);
  return /*#__PURE__*/_jsxs(PopoverTriggerContext.Provider, {
    value: {
      isOpen,
      close
    },
    children: [triggerMarkup, /*#__PURE__*/_jsxs(Overlay, { ...mergeProps(rest, {
        borderOffset: "var(--o-ui-global-scale-charlie)",
        zIndex,
        className: "o-ui-popover-overlay",
        as,
        ref: overlayRef
      }, overlayProps),
      children: [popover, /*#__PURE__*/_jsx(OverlayArrow, { ...arrowProps
      })]
    })]
  });
}
export const PopoverTrigger = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerPopoverTrigger, { ...props,
  forwardedRef: ref
}));
PopoverTrigger.displayName = "PopoverTrigger";