import "./Radio.css";
import { Box } from "../../box";
import { useImperativeHandle, useMemo, useRef } from "react";
import { cssModule, forwardRef, mergeProps, omitProps, resolveChildren, useAutoFocus, useChainedEventCallback, useCheckableProps, useControllableState, useEventCallback, useForwardInputApi, useSlots } from "../../shared";
import { Text } from "../../text";
import { VisuallyHidden } from "../../visually-hidden";
import { isNil, isNumber } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerRadio(props) {
  const [checkableProps] = useCheckableProps(props);
  const {
    value,
    name,
    checked,
    defaultChecked,
    autoFocus,
    validationState,
    onChange,
    onCheck,
    reverse,
    tabIndex,
    active,
    focus,
    hover,
    disabled,
    as = "label",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(omitProps(props, ["role"]), checkableProps);
  const [isChecked, setIsChecked] = useControllableState(checked, defaultChecked, false);
  const labelRef = useRef();
  const inputRef = useRef();
  useAutoFocus(inputRef, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const forwardInputApi = useForwardInputApi(inputRef);
  useImperativeHandle(forwardedRef, () => {
    return forwardInputApi(labelRef);
  });
  const handleChange = useChainedEventCallback(onChange, () => {
    setIsChecked(!isChecked);
  });
  const handleCheck = useEventCallback(event => {
    onCheck(event, value);
  });
  const content = resolveChildren(children);
  const {
    text,
    icon,
    counter
  } = useSlots(content, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    text: {
      color: "inherit",
      className: "o-ui-radio-label"
    },
    icon: {
      size: "sm",
      className: "o-ui-radio-icon"
    },
    counter: {
      variant: "divider",
      color: "inherit",
      reverse,
      pushed: true,
      className: "o-ui-radio-counter"
    }
  }), [reverse]));
  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-radio", isChecked && "checked", reverse && "reverse", validationState && validationState, disabled && "disabled", active && "active", focus && "focus", hover && "hover"),
      as,
      ref: labelRef
    }),
    children: [/*#__PURE__*/_jsx(VisuallyHidden, {
      as: "input",
      type: "radio",
      value: value,
      name: name,
      checked: isChecked,
      onChange: !isNil(onCheck) ? handleCheck : handleChange,
      disabled: disabled,
      tabIndex: tabIndex,
      "data-type": typeof value,
      "aria-invalid": validationState === "invalid",
      ref: inputRef
    }), /*#__PURE__*/_jsx("span", {
      className: "o-ui-radio-button"
    }), text, icon, counter]
  });
}
export const Radio = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerRadio, { ...props,
  forwardedRef: ref
}));
Radio.displayName = "Radio";