import "./RadioGroup.css";
import { ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
export interface InnerRadioGroupProps {
    /**
     * The value of the radio group.
     */
    value?: string;
    /**
     * The initial value of `value`.
     */
    defaultValue?: string;
    /**
     * Whether or not a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether the group should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * Radio group name.
     */
    name?: string;
    /**
     * Called when any of the group elements is checked or unchecked.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {string} value - The new value.
     * @returns {void}
     */
    onChange?: (event: SyntheticEvent, value: string) => void;
    /**
     * Whether or not the radio group should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * The orientation of the group elements.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * The space between the group elements.
     */
    gap?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | string;
    /**
     * Whether the group elements are forced onto one line or can wrap onto multiple lines
     */
    wrap?: boolean;
    /**
     * Invert the order of the radio button and his label.
     */
    reverse?: boolean;
    /**
     * Whether or not the radio group is disabled.
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerRadioGroup(props: InnerRadioGroupProps): JSX.Element;
export declare const RadioGroup: import("../../shared").OrbitComponent<HTMLElement, InnerRadioGroupProps>;
