import "./RadioGroup.css";
import { CheckableContext, Keys, augmentElement, forwardRef, mergeProps, omitProps, useAutoFocusChild, useControllableState, useEventCallback, useFocusManager, useFocusScope, useId, useKeyboardNavigation, useKeyedRovingFocus, useMergedRefs } from "../../shared";
import { Children } from "react";
import { Group } from "../../group";
import { isNil, isNumber } from "lodash";
import { useFieldInputProps } from "../../field";
import { useGroupInput } from "../../input";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
const NavigationKeyBinding = {
  default: {
    previous: [Keys.arrowLeft, Keys.arrowUp],
    next: [Keys.arrowRight, Keys.arrowDown],
    first: [Keys.home],
    last: [Keys.end]
  },
  toolbar: {
    previous: [Keys.arrowUp],
    next: [Keys.arrowDown]
  }
};
const RadioKeyProp = "value";
export function InnerRadioGroup(props) {
  const [toolbarProps, isInToolbar] = useToolbarProps();
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    value,
    defaultValue,
    required,
    validationState,
    name,
    onChange,
    autoFocus,
    orientation = "vertical",
    gap,
    wrap,
    reverse,
    disabled,
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, toolbarProps, omitProps(fieldProps, ["fluid", "size"]));
  const [checkedValue, setCheckedValue] = useControllableState(value, defaultValue, null);
  const [focusScope, setFocusRef] = useFocusScope();
  const groupRef = useMergedRefs(setFocusRef, forwardedRef);
  const handleArrowSelect = useEventCallback((_event, element) => {
    // When a number value is provided it's converted to a string when a new value is selected using the keyboard arrows.
    const newValue = element.dataset.type === "number" ? parseInt(element.value) : element.value;
    setCheckedValue(newValue);
  });
  const focusManager = useFocusManager(focusScope, {
    keyProp: RadioKeyProp
  });
  useKeyedRovingFocus(focusScope, checkedValue, {
    keyProp: RadioKeyProp
  });
  useAutoFocusChild(focusManager, {
    target: value !== null && value !== void 0 ? value : defaultValue,
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const navigationMode = isInToolbar ? "toolbar" : "default";
  const navigationProps = useKeyboardNavigation(focusManager, NavigationKeyBinding[navigationMode], !isInToolbar ? {
    onSelect: handleArrowSelect
  } : undefined);
  const {
    groupProps,
    itemProps
  } = useGroupInput({
    cssModule: "o-ui-radio-group",
    role: "radiogroup",
    required,
    validationState,
    orientation,
    gap,
    wrap,
    reverse,
    disabled,
    isInField,
    groupRef
  });
  const handleCheck = useEventCallback((event, newValue) => {
    setCheckedValue(newValue);

    if (!isNil(onChange)) {
      onChange(event, newValue);
    }
  });
  const groupName = useId(name, "radio-group");
  return /*#__PURE__*/_jsx(Group, { ...mergeProps(rest, navigationProps, groupProps),
    children: /*#__PURE__*/_jsx(CheckableContext.Provider, {
      value: {
        onCheck: handleCheck,
        checkedValue
      },
      children: Children.map(children, x => {
        return augmentElement(x, { ...itemProps,
          role: "radio",
          name: groupName
        });
      })
    })
  });
}
export const RadioGroup = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerRadioGroup, { ...props,
  forwardedRef: ref
}));
RadioGroup.displayName = "RadioGroup";