import "./Select.css";
import { augmentElement, cssModule, forwardRef, mergeProps } from "../../shared";
import { DisclosureArrow } from "../../disclosure";
import { HiddenSelect } from "./HiddenSelect";
import { Listbox } from "../../listbox";
import { Overlay } from "../../overlay";
import { Text } from "../../text";
import { isNil } from "lodash";
import { useFieldInputProps } from "../../field";
import { useSelect } from "./useSelect"; // used to generate OverlayProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
export function InnerSelect(props) {
  const [fieldProps] = useFieldInputProps();
  const {
    id,
    open,
    defaultOpen,
    selectedKey: selectedKeyProp,
    defaultSelectedKey,
    placeholder,
    required,
    validationState,
    onSelectionChange,
    onOpenChange,
    variant = "outline",
    icon,
    direction = "bottom",
    align = "start",
    autoFocus,
    name,
    fluid,
    disabled,
    allowFlip = true,
    allowPreventOverflow = true,
    zIndex = 10000,
    active,
    focus,
    hover,
    "aria-label": ariaLabel,
    // Usually provided by the field inputs.
    "aria-labelledby": ariaLabelledBy,
    "aria-describedby": ariaDescribedBy,
    overlayProps: overlayPropsProp,
    as: TriggerType = "button",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, fieldProps);
  const {
    selectedKey,
    selectedItem,
    isOpen,
    triggerProps,
    overlayProps,
    listboxProps
  } = useSelect(children, {
    id,
    open,
    defaultOpen,
    selectedKey: selectedKeyProp,
    defaultSelectedKey,
    onSelectionChange,
    onOpenChange,
    direction,
    align,
    autoFocus,
    disabled,
    allowFlip,
    allowPreventOverflow,
    allowResponsiveMenuWidth: variant !== "ghost",
    ariaLabel,
    ariaLabelledBy,
    ariaDescribedBy,
    overlayProps: overlayPropsProp,
    ref: forwardedRef
  });
  const iconMarkup = icon && augmentElement(icon, {
    className: "o-ui-select-icon",
    size: "sm"
  });
  const selectedIconMarkup = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.icon) && augmentElement(selectedItem.icon, {
    size: "sm",
    className: "o-ui-select-value-start-icon"
  });

  const selectedTextMarkup = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.text) && /*#__PURE__*/_jsx(Text, {
    className: "o-ui-select-value-text",
    children: selectedItem.text
  });

  const selectedEndIconMarkup = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.endIcon) && augmentElement(selectedItem.endIcon, {
    size: "sm",
    className: "o-ui-select-value-end-icon"
  });
  const valueMarkup = isNil(selectedItem) ? placeholder && /*#__PURE__*/_jsx(Text, {
    className: "o-ui-select-placeholder",
    children: placeholder
  }) : /*#__PURE__*/_jsxs("span", {
    className: "o-ui-select-value",
    children: [selectedIconMarkup, selectedTextMarkup, selectedEndIconMarkup]
  });
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(HiddenSelect, {
      name: name,
      selectedKey: selectedKey,
      required: required,
      validationState: validationState,
      disabled: disabled
    }), /*#__PURE__*/_jsxs(TriggerType, { ...mergeProps(rest, {
        className: cssModule("o-ui-select-trigger", variant, validationState, fluid && "fluid", active && "active", focus && "focus", hover && "hover")
      }, triggerProps),
      children: [iconMarkup, valueMarkup, /*#__PURE__*/_jsx(DisclosureArrow, {
        open: isOpen,
        size: "sm"
      })]
    }), /*#__PURE__*/_jsx(Overlay, { ...overlayProps,
      zIndex: zIndex,
      children: /*#__PURE__*/_jsx(Listbox, { ...listboxProps
      })
    })]
  });
}
export const Select = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerSelect, { ...props,
  forwardedRef: ref
}));
Select.displayName = "Select";