import { FocusTarget } from "./focusTarget";
import { useEffect } from "react";
import { disposables } from "./useDisposables";
import { useChainedEventCallback } from "./useChainedEventCallback";
import { useEventCallback } from "./useEventCallback";

function useAbstractAutoFocus({
  isDisabled,
  delay,
  onFocus
}) {
  useEffect(() => {
    const d = disposables();

    if (!isDisabled) {
      if (delay) {
        d.setTimeout(() => {
          onFocus();
        }, delay);
      } else {
        d.nextFrame(() => {
          onFocus();
        });
      }
    }

    return () => {
      d.dispose();
    };
  }, [isDisabled, delay, onFocus]);
}

export function useAutoFocus(targetRef, {
  isDisabled,
  delay,
  onFocus
} = {}) {
  useAbstractAutoFocus({
    isDisabled,
    delay,
    onFocus: useChainedEventCallback(onFocus, () => {
      var _targetRef$current, _targetRef$current2;

      if (!((_targetRef$current = targetRef.current) !== null && _targetRef$current !== void 0 && _targetRef$current.hasAttribute("disabled")) && !((_targetRef$current2 = targetRef.current) !== null && _targetRef$current2 !== void 0 && _targetRef$current2.contains(document.activeElement))) {
        targetRef.current.focus();
      }
    })
  });
}
export function useAutoFocusChild(focusManager, {
  target = FocusTarget.first,
  isDisabled,
  delay,
  canFocus,
  onFocus,
  onNotFound
} = {}) {
  useAbstractAutoFocus({
    isDisabled: isDisabled,
    delay,
    onFocus: useEventCallback(() => {
      // Do not autofocus another child if there is already one focused.
      if (!focusManager.hasFocus()) {
        focusManager.focusTarget(target, {
          canFocus,
          onFocus,
          onNotFound
        });
      }
    })
  });
}