import "./Switch.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { InteractionStatesProps } from "../../shared";
export interface InnerSwitchProps extends InteractionStatesProps {
    /**
     * @ignore
     */
    name?: string;
    /**
     * @ignore
     */
    tabIndex?: number;
    /**
     * A controlled checked state value.
     */
    checked?: boolean;
    /**
     * The initial value of `checked` when uncontrolled.
     */
    defaultChecked?: boolean;
    /**
     * Whether or not the checkbox should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether or not the checkbox should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * A checkbox can vary in size.
     */
    size?: "sm" | "md";
    /**
     * Invert the order the checkmark box and the label.
     */
    reverse?: boolean;
    /**
     * Called when the switch checked state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onChange?: (event: SyntheticEvent) => void;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerSwitch(props: InnerSwitchProps): JSX.Element;
export declare const Switch: import("../../shared").OrbitComponent<HTMLElement, InnerSwitchProps>;
export declare type SwitchProps = ComponentProps<typeof Switch>;
