import "./Switch.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { forwardRef, mergeProps, omitProps, resolveChildren, useSlots } from "../../shared";
import { Text } from "../../text";
import { VisuallyHidden } from "../../visually-hidden";
import { embeddedIconSize } from "../../icons";
import { useCheckbox } from "../../checkbox";
import { useFieldInputProps } from "../../field";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerSwitch(props) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps, isInField] = useFieldInputProps();
  const {
    id,
    checked,
    defaultChecked,
    autoFocus,
    required,
    validationState,
    onChange,
    size,
    reverse,
    name,
    tabIndex,
    active,
    focus,
    hover,
    disabled,
    as = "label",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, omitProps(toolbarProps, ["orientation"]), fieldProps);
  const {
    wrapperProps,
    inputProps
  } = useCheckbox({
    cssModule: "o-ui-switch",
    isInField,
    id,
    checked,
    defaultChecked,
    autoFocus,
    required,
    validationState,
    onChange,
    size,
    reverse,
    name,
    tabIndex,
    active,
    focus,
    hover,
    disabled,
    forwardedRef
  });
  const content = resolveChildren(children);
  const {
    text,
    icon,
    counter
  } = useSlots(content, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    text: {
      color: "inherit",
      size,
      className: "o-ui-switch-label"
    },
    icon: {
      size: embeddedIconSize(size),
      className: "o-ui-switch-icon"
    },
    counter: {
      variant: "divider",
      color: "inherit",
      size,
      reverse,
      pushed: true,
      className: "o-ui-switch-counter"
    }
  }), [size, reverse]));
  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      as
    }, wrapperProps),
    children: [/*#__PURE__*/_jsx(VisuallyHidden, { ...inputProps
    }), /*#__PURE__*/_jsx("span", {
      className: "o-ui-switch-control"
    }), text, icon, counter]
  });
}
export const Switch = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerSwitch, { ...props,
  forwardedRef: ref
}));
Switch.displayName = "Switch";