import "./Tabs.css";
import { Box } from "../../box";
import { Keys, forwardRef, mergeProps, useAutoFocusChild, useFocusManager, useFocusScope, useKeyboardNavigation, useKeyedRovingFocus, useMergedRefs } from "../../shared";
import { Tab, TabKeyProp } from "./Tab";
import { isNumber } from "lodash";
import { useTabsContext } from "./TabsContext";
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";
const NavigationKeyBinding = {
  horizontal: {
    previous: [Keys.arrowLeft],
    next: [Keys.arrowRight],
    first: [Keys.home],
    last: [Keys.end]
  },
  vertical: {
    previous: [Keys.arrowUp],
    next: [Keys.arrowDown],
    first: [Keys.home],
    last: [Keys.end]
  }
};
export function InnerTabList({
  tabs,
  autoFocus,
  forwardedRef,
  ...rest
}) {
  const {
    selectedKey,
    orientation
  } = useTabsContext();
  const [focusScope, setFocusRef] = useFocusScope();
  const tabRef = useMergedRefs(setFocusRef, forwardedRef);
  const focusManager = useFocusManager(focusScope, {
    keyProp: TabKeyProp
  });
  useKeyedRovingFocus(focusScope, selectedKey, {
    keyProp: TabKeyProp
  });
  useAutoFocusChild(focusManager, {
    target: selectedKey,
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const navigationProps = useKeyboardNavigation(focusManager, NavigationKeyBinding[orientation]);
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: "o-ui-tab-list",
      role: "tablist",
      "aria-orientation": orientation,
      ref: tabRef
    }, navigationProps),
    children: tabs.map(({
      key,
      elementType: ElementType = Tab,
      ref,
      tabId,
      panelId,
      props
    }) => /*#__PURE__*/_createElement(ElementType, { ...props,
      tab: {
        key,
        tabId,
        panelId
      },
      key: key,
      ref: ref
    }))
  });
}
export const TabList = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTabList, { ...props,
  forwardedRef: ref
}));