import "./Tabs.css";
import { AriaLabelingProps, DomProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
export interface InnerTabsProps extends DomProps, AriaLabelingProps {
    /**
     * A controlled selected key.
     */
    selectedKey: string;
    /**
     * The initial value of `selectedKey` when uncontrolled.
     */
    defaultSelectedKey: string;
    /**
     * Called when the selected tab change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {string} key - The selected tab key.
     * @returns {void}
     */
    onSelectionChange?: (event: SyntheticEvent, key: string) => void;
    /**
     * Whether or not keyboard navigation changes focus between tabs but doens't activate it.
     */
    manual?: boolean;
    /**
     * Whether or not the first focusable tab should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the tabs take up the width of the container.
     */
    fluid?: boolean;
    /**
     * The orientation of the tabs elements.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * Tabs title for screen readers.
     */
    "aria-label": string;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerTabs({ id, selectedKey: selectedKeyProp, defaultSelectedKey, onSelectionChange, manual, autoFocus, fluid, orientation, "aria-label": ariaLabel, children, forwardedRef, ...rest }: InnerTabsProps): JSX.Element;
export declare const Tabs: import("../../shared").OrbitComponent<HTMLElement, InnerTabsProps>;
export declare type TabsProps = ComponentProps<typeof Tabs>;
