import "./Tag.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { InteractionStatesProps } from "../../shared";
export interface InnerTagProps extends InteractionStatesProps {
    /**
     * The tag style to use.
     */
    variant?: "solid" | "outline";
    /**
     * Called when the remove button is clicked.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onRemove?: (event: SyntheticEvent) => void;
    /**
     * Whether or not the tag is disabled.
     */
    disabled?: boolean;
    /**
     * Whether the tag take up the width of its container.
     */
    fluid?: boolean;
    /**
     * A tag can vary in size.
     */
    size?: "sm" | "md";
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerTag({ variant, onRemove, disabled, fluid, size, active, focus, hover, as, children, forwardedRef, ...rest }: InnerTagProps): JSX.Element;
export declare const Tag: import("../../shared").OrbitComponent<HTMLElement, InnerTagProps>;
export declare type TagProps = ComponentProps<typeof Tag>;
