import "./TagList.css";
import { CollectionItem } from "../../collection";
import { ComponentProps, ElementType, ForwardedRef, ReactNode, SyntheticEvent } from "react";
import { TagProps } from "./Tag";
export interface InnerTagListProps {
    /**
     * A tag list can vary in size.
     */
    size?: "sm" | "md";
    /**
     * Called when an item is removed from the list.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {string} key - The item key.
     * @returns {void}
     */
    onRemove?: (event: SyntheticEvent, key: string) => void;
    /**
     * Called when all items are cleared from the list.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onClear?: (event: SyntheticEvent) => void;
    /**
     * Whether or not tag items should be render as readonly.
     */
    readOnly?: boolean;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export interface TagItemProps extends Omit<TagProps, "children"> {
    item?: CollectionItem;
    size: "sm" | "md";
    onRemove: any;
    readOnly: boolean;
}
export declare function InnerTagList({ size, onRemove, onClear, readOnly, as, forwardedRef, children, ...rest }: InnerTagListProps): JSX.Element;
export declare const TagList: import("../../shared").OrbitComponent<HTMLElement, InnerTagListProps>;
export declare type TagListProps = ComponentProps<typeof TagList>;
