import "./TagList.css";
import { Box } from "../../box";
import { Button } from "../../button";
import { useCollection } from "../../collection";
import { Tag } from "./Tag";
import { forwardRef, mergeProps, useEventCallback } from "../../shared";
import { isNil } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

function TagItem({
  item,
  size,
  onRemove,
  readOnly,
  ...rest
}) {
  const handleRemove = useEventCallback(event => {
    if (!isNil(onRemove)) {
      onRemove(event, item.key);
    }
  });
  return /*#__PURE__*/_jsx(Tag, { ...mergeProps(rest, {
      variant: "outline",
      size,
      className: "o-ui-tag-list-item",
      onRemove: !readOnly ? handleRemove : undefined
    }),
    children: item.content
  });
}

export function InnerTagList({
  size,
  onRemove,
  onClear,
  readOnly,
  as = "div",
  forwardedRef,
  children,
  ...rest
}) {
  const nodes = useCollection(children);

  const clearButtonMarkup = !isNil(onClear) && !readOnly && nodes.length > 0 && /*#__PURE__*/_jsx(Button, {
    variant: "ghost",
    size: size,
    onClick: onClear,
    className: "o-ui-tag-list-clear-button",
    children: "Clear all"
  });

  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      className: "o-ui-tag-list",
      as,
      ref: forwardedRef
    }),
    children: [nodes.map(x => /*#__PURE__*/_jsx(TagItem, {
      item: x,
      size: size,
      onRemove: onRemove,
      readOnly: readOnly
    }, x.key)), clearButtonMarkup]
  });
}
export const TagList = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTagList, { ...props,
  forwardedRef: ref
}));
TagList.displayName = "TagList";