import "./TextArea.css";
import { Box } from "../../box";
import { useCallback, useLayoutEffect, useState } from "react";
import { cssModule, forwardRef, mergeProps, useControllableState, useEventCallback } from "../../shared";
import { isNil } from "lodash";
import { useFieldInputProps } from "../../field";
import { useInput, useInputButton, wrappedInputPropsAdapter } from "../../input"; // used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

const pxToInt = value => {
  return !isNil(value) ? parseInt(value.replace("px", ""), 10) : 0;
};

export function InnerTextArea(props) {
  const [fieldProps] = useFieldInputProps();
  const {
    id,
    value,
    defaultValue,
    placeholder,
    resize,
    required,
    validationState,
    type = "text",
    autoFocus,
    button,
    disabled,
    readOnly,
    fluid,
    loading,
    rows: rowsProp,
    maxRows,
    active,
    focus,
    hover,
    wrapperProps: userWrapperProps,
    as = "div",
    forwardedRef,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(fieldProps));
  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const [rows, setRows] = useState(rowsProp);
  const handleChange = useEventCallback(event => {
    setValue(event.target.value);
  });
  const {
    wrapperProps,
    inputProps,
    inputRef
  } = useInput({
    cssModule: "o-ui-text-area",
    id,
    value: inputValue,
    placeholder,
    required,
    validationState,
    onChange: handleChange,
    type,
    autoFocus,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    forwardedRef
  });
  const adjustRows = useCallback(() => {
    const input = inputRef.current;
    const {
      paddingBottom,
      paddingTop,
      lineHeight
    } = window.getComputedStyle(input);
    const padding = pxToInt(paddingTop) + pxToInt(paddingBottom);
    const currentRows = Math.floor((input.scrollHeight - padding) / pxToInt(lineHeight));
    const newRows = !isNil(maxRows) && currentRows > maxRows ? maxRows : currentRows;
    setRows(newRows);
  }, [inputRef, maxRows]);
  useLayoutEffect(() => {
    adjustRows();
  }, [adjustRows, inputValue]);
  const buttonMarkup = useInputButton(button, !disabled && !readOnly);

  const content = /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx("textarea", { ...mergeProps(rest, {
        rows,
        style: {
          ["--o-ui-resize"]: resize
        }
      }, inputProps)
    }), buttonMarkup]
  });

  return /*#__PURE__*/_jsx(Box, { ...mergeProps(userWrapperProps, {
      className: cssModule("o-ui-input", buttonMarkup && "has-button"),
      as
    }, wrapperProps),
    children: content
  });
}
export const TextArea = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTextArea, { ...props,
  forwardedRef: ref
}));
TextArea.displayName = "TextArea";