import "./PasswordInput.css";
import { BoxProps as BoxPropsForDocumentation } from "../../box";
import { ComponentProps, ElementType, ForwardedRef, ReactElement, SyntheticEvent } from "react";
interface BoxProps extends BoxPropsForDocumentation {
}
export interface InnerPasswordInputProps {
    /**
     * A controlled value.
     */
    value?: string;
    /**
     * The default value of `value` when uncontrolled.
     */
    defaultValue?: string;
    /**
     * Temporary text that occupies the input when it is empty.
     */
    placeholder?: string;
    /**
     * Label identifying the input.
     */
    label?: string;
    /**
     * Whether or not a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether or not the input should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * Called when the text input value change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @returns {void}
     */
    onChange?: (event: SyntheticEvent) => void;
    /**
     * Whether or not the input should autofocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * [Icon](/?path=/docs/icon--default-story) component rendered before the value.
     */
    icon?: ReactElement;
    /**
     * Whether or not the input take up the width of its container.
     */
    fluid?: boolean;
    /**
     * Whether or not to render a loader.
     */
    loading?: boolean;
    /**
     * @ignore
     */
    disabled?: boolean;
    /**
     * @ignore
     */
    readOnly?: boolean;
    /**
     * Additional props to render on the wrapper element.
     */
    wrapperProps?: Partial<BoxProps>;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerPasswordInput({ value, defaultValue, wrapperProps, forwardedRef, ...rest }: InnerPasswordInputProps): JSX.Element;
export declare const PasswordInput: import("../../shared").OrbitComponent<"input", InnerPasswordInputProps>;
export declare type PasswordInputProps = ComponentProps<typeof PasswordInput>;
export {};
