import "./PasswordInput.css";
import { EyeIcon, PrivacyIcon } from "../../icons";
import { IconButton } from "../../button";
import { TextInput } from "./TextInput";
import { forwardRef, isNilOrEmpty, mergeProps, useControllableState, useEventCallback } from "../../shared";
import { useState } from "react"; // used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
export function InnerPasswordInput({
  value,
  defaultValue,
  wrapperProps,
  forwardedRef,
  ...rest
}) {
  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const [isHidden, setIsHidden] = useState(true);
  const handleChange = useEventCallback(event => {
    setValue(event.target.value);
  });
  const handleShowValue = useEventCallback(() => {
    setIsHidden(x => !x);
  });

  const showButtonMarkup = !isNilOrEmpty(inputValue) && /*#__PURE__*/_jsx(IconButton, {
    variant: "ghost",
    onClick: handleShowValue,
    className: "o-ui-password-input-show-button",
    title: "Toggle password visibility",
    "aria-label": "Toggle password visibility",
    children: isHidden ? /*#__PURE__*/_jsx(EyeIcon, {}) : /*#__PURE__*/_jsx(PrivacyIcon, {})
  });

  return /*#__PURE__*/_jsx(TextInput, { ...mergeProps(rest, {
      value: inputValue,
      onChange: handleChange,
      wrapperProps: mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
        className: "o-ui-password-input"
      }),
      type: isHidden ? "password" : "text",
      button: showButtonMarkup || undefined,
      ref: forwardedRef
    })
  });
}
export const PasswordInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerPasswordInput, { ...props,
  forwardedRef: ref
}));
PasswordInput.displayName = "PasswordInput";