import "./TextInput.css";
import { Box } from "../../box";
import { cssModule, forwardRef, mergeProps, omitProps, useControllableState, useEventCallback } from "../../shared";
import { useFieldInputProps } from "../../field";
import { useInput, useInputButton, useInputIcon, wrappedInputPropsAdapter } from "../../input";
import { useToolbarProps } from "../../toolbar"; // used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerTextInput(props) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps] = useFieldInputProps();
  const {
    id,
    value,
    defaultValue,
    placeholder,
    required,
    validationState,
    type = "text",
    autoFocus,
    icon,
    button,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    wrapperProps: userWrapperProps,
    as: TriggerType = "input",
    forwardedRef,
    ...rest
  } = mergeProps(props, omitProps(toolbarProps, ["orientation"]), wrappedInputPropsAdapter(fieldProps));
  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const handleChange = useEventCallback(event => {
    setValue(event.target.value);
  });
  const {
    wrapperProps,
    inputProps
  } = useInput({
    cssModule: "o-ui-text-input",
    id,
    value: inputValue,
    placeholder,
    required,
    validationState,
    onChange: handleChange,
    type,
    autoFocus,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    forwardedRef
  });
  const iconMarkup = useInputIcon(icon, {
    disabled
  });
  const buttonMarkup = useInputButton(button, !disabled && !readOnly);

  const content = /*#__PURE__*/_jsxs(_Fragment, {
    children: [iconMarkup, /*#__PURE__*/_jsx(TriggerType, { ...mergeProps(rest, inputProps)
    }), buttonMarkup]
  });

  return /*#__PURE__*/_jsx(Box, { ...mergeProps(userWrapperProps, {
      className: cssModule("o-ui-input", iconMarkup && "has-icon", disabled && "disabled", buttonMarkup && "has-button")
    }, wrapperProps),
    children: content
  });
}
export const TextInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTextInput, { ...props,
  forwardedRef: ref
}));
TextInput.displayName = "TextInput";