import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerToolbarProps {
    /**
         * Whether or not the toolbar should autoFocus the first tabbable element on render.
         */
    autoFocus?: boolean | number;
    /**
     * The orientation of the elements.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * The horizontal alignment of the elements.
     */
    align?: "start" | "end" | "center";
    /**
     * The vertical alignment of the elements.
     */
    verticalAlign?: "start" | "end" | "center";
    /**
     * The space between the elements.
     */
    gap?: (0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13) | string;
    /**
     * Whether or not the elements are forced onto one line or can wrap onto multiple lines
     */
    wrap?: boolean;
    /**
     * Whether the toolbar take up the width of its container.
     */
    fluid?: boolean;
    /**
     * Whether or not the toolbar elements are disabled.
     */
    disabled?: boolean;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
    * @ignore
    */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerToolbar({ autoFocus, orientation, align, verticalAlign, gap, wrap, disabled, as, children, forwardedRef, ...rest }: InnerToolbarProps): JSX.Element;
export declare const Toolbar: import("../../shared").OrbitComponent<HTMLElement, InnerToolbarProps>;
export declare type ToolbarProps = ComponentProps<typeof Toolbar>;
