import { Flex, useFlexAlignment, useFlexDirection } from "../../layout";
import { Keys, forwardRef, mergeProps, useAutoFocusChild, useFocusManager, useFocusScope, useKeyboardNavigation, useMergedRefs, useRovingFocus } from "../../shared";
import { ToolbarContext } from "./ToolbarContext";
import { isNil, isNumber } from "lodash";
import { jsx as _jsx } from "react/jsx-runtime";
const NavigationKeyBinding = {
  horizontal: {
    previous: [Keys.arrowLeft],
    next: [Keys.arrowRight],
    first: [Keys.home],
    last: [Keys.end]
  },
  vertical: {
    previous: [Keys.arrowUp],
    next: [Keys.arrowDown],
    first: [Keys.home],
    last: [Keys.end]
  }
};
export function InnerToolbar({
  autoFocus,
  orientation = "horizontal",
  align,
  verticalAlign,
  gap = 5,
  wrap,
  disabled,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const [focusScope, setFocusRef] = useFocusScope();
  const containerRef = useMergedRefs(setFocusRef, forwardedRef);
  const focusManager = useFocusManager(focusScope);
  useRovingFocus(focusScope);
  useAutoFocusChild(focusManager, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const arrowNavigationProps = useKeyboardNavigation(focusManager, NavigationKeyBinding[orientation]);
  const directionProps = useFlexDirection(orientation);
  const alignProps = useFlexAlignment(orientation, align, orientation === "horizontal" ? verticalAlign !== null && verticalAlign !== void 0 ? verticalAlign : "center" : verticalAlign);
  return /*#__PURE__*/_jsx(Flex, { ...mergeProps(rest, {
      role: "toolbar",
      gap,
      wrap: !isNil(wrap) ? "wrap" : undefined,
      as,
      ref: containerRef,
      "aria-orientation": orientation
    }, directionProps, alignProps, arrowNavigationProps),
    children: /*#__PURE__*/_jsx(ToolbarContext.Provider, {
      value: {
        orientation,
        disabled
      },
      children: children
    })
  });
}
export const Toolbar = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerToolbar, { ...props,
  forwardedRef: ref
}));
Toolbar.displayName = "Toolbar";