import "./Tooltip.css";
import { ComponentProps, ElementType, ForwardedRef, ReactElement, ReactNode, SyntheticEvent } from "react";
interface InnerTooltipTriggerProps {
    /**
    * Whether or not to show the tooltip.
    */
    open?: boolean;
    /**
     * The initial value of `open` when in auto controlled mode.
     */
    defaultOpen?: boolean;
    /**
     * Position of the tooltip element related to the trigger.
     */
    position?: "auto" | "auto-start" | "auto-end" | "top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end";
    /**
     * Called when the open state change.
     * @param {SyntheticEvent} event - React's original SyntheticEvent.
     * @param {boolean} isOpen - Indicate if the tooltip is visible.
     * @returns {void}
     */
    onOpenChange?: (event: SyntheticEvent, isOpen: boolean) => void;
    /**
     * Whether or not the tooltip should be disabled, independent from the trigger.
     */
    disabled?: boolean;
    /**
     * Whether or not the tooltip element can flip when it will overflow it's boundary area.
     */
    allowFlip?: boolean;
    /**
     * z-index of the popover element.
     */
    zIndex?: number;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    containerElement?: HTMLElement;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function parseTooltipTrigger(children: ReactNode): [ReactElement<any, string | import("react").JSXElementConstructor<any>>, ReactElement<any, string | import("react").JSXElementConstructor<any>>];
export declare function InnerTooltipTrigger({ open, defaultOpen, position: positionProp, onOpenChange, disabled, allowFlip, containerElement, zIndex, as, children, forwardedRef, ...rest }: InnerTooltipTriggerProps): JSX.Element;
export declare const TooltipTrigger: import("../../shared").OrbitComponent<HTMLElement, InnerTooltipTriggerProps>;
export declare type TooltipTriggerProps = ComponentProps<typeof TooltipTrigger>;
export {};
